Learn R Programming

hpoPlot (version 2.2)

p.values.for.occurrence.of.term.in.group: Get p-values for observing at least as many of each term as have been in phenotypes given information content

Description

Get p-values for observing at least as many of each term as have been in phenotypes given information content

Usage

p.values.for.occurrence.of.term.in.group(hpo.terms, hpo.phenotypes, terms.freq)

Arguments

hpo.terms
R-Object representation of HPO
hpo.phenotypes
List of HPO term character vectors
terms.freq
Numeric vector of population frequencies of terms

Value

  • Numeric vector of log p-values named by correspnding term