Learn R Programming

hpoPlot (version 2.2)

remove.terms.with.less.than.n.occurrences: Remove terms with less than certain number of occurrences

Description

Remove terms with less than certain number of occurrences

Usage

remove.terms.with.less.than.n.occurrences(hpo.terms, terms, plotting.context, n)

Arguments

hpo.terms
R-Object representation of HPO
terms
Character vector of HPO terms
plotting.context
List object with hpo.phenotypes slot for list of character vectors of terms
n
Integer

Value

  • Character vector

See Also

n.most.frequent.terms, remove.uninformative.for.plot

Examples

Run this code
data(hpo.terms)
remove.terms.with.less.than.n.occurrences(hpo.terms,
	c("HP:0001873"), list(hpo.phenotypes=list("HP:0001873", "HP:0001902")), 2)

Run the code above in your browser using DataLab