Learn R Programming

hpoPlot (version 1.0)

swap.out.alt.ids: Swap Out Alternative/Previous IDs

Description

Function to replace the terms in a set with their updated/replacement IDs (if they exist) in the given HPO object.

Usage

swap.out.alt.ids(hpo.terms, hpo.term.set, remove.dead = FALSE)

Arguments

hpo.terms
An R-Object representing the HPO, as returned by get.hpo.terms.
hpo.term.set
Character vector of HPO terms.
remove.dead
Boolean to dictate whether to remove terms which are not in the HPO object given. Defaults to FALSE.

Value

  • Character vector of HPO terms.

Examples

Run this code
data(hpo)
	old.code.for.migraine <- "HP:0007194"
	current.code.for.migraine <- swap.out.alt.ids(hpo.terms, old.code.for.migraine)

Run the code above in your browser using DataLab